package se.deig.tts;


import java.io.File;
import java.util.List;

public interface TTSInterface {
	/**
	 * Returns the (unique) name of this TTS generator.
	 * @return the name of the TTS generator.
	 */
	public String getTTSEngineName();
	
	/**
	 * Returns information about this TTS.
	 * @return a short description of the TTS.
	 */
	
	
	/**
	 * Tells if this TTS is available on this system
	 * @return if this TTS is available on this system
	 */
	public boolean isTTSAvailable();
	
	
	public String getInfo();
	
	/**
	 * Returns a list of available natural languages that this generator supports.
	 * @return a list with language names.
	 */
	public List<String> getLanguages();
	
	/**
	 * Returns a list of voices available for specified given language.
	 * @param language the language to return a list of voices for. 
	 * @return a list with voice names.
	 */
	public List<String> getVoices(String language);

	
	/**
	 * Tells if this TTS will adjust the speed according to the speed parameter.
	 * @return if this TTS can adjust speaking speed.
	 */
	public boolean supportsSpeedParameter();
	
	/**
	 * Tells if this TTS will adjust the pitch according to the speed parameter.
	 * @return if this TTS can adjust speaking pitch.
	 */
	public boolean supportsPitchParameter();
	
	
	/**
	 * Generates a wav-file with the specified line using the specified voice and language. 
	 * @param line the text line to generate.
	 * @param language the name of the language to use.
	 * @param voice a name of the voice to use
	 * @param speed the speed adjustment as a number in the range -5 (super slow) to 5 (super fast). If this TTS does not support speed specification, this parameter is ignored.
	 * @param pitch the pitch adjustment as a number in the range -5 (super low) to 5 (super high). If this TTS does not support pitch specification, this parameter is ignored.
	 * @param fileLocation the local file where the result is saved.
	 * @return if the generation was successful or not.
	 */
	public boolean createWavFile(String line, String language, String voice, int speed, int pitch, File fileLocation);
}
